@@ -2,7 +2,7 @@
 # Copyright 1999-2003 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
 # Author:  Martin Schlemmer <azarah@gentoo.org>
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/depscan.sh,v 1.23 2004/02/08 11:42:21 azarah Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/depscan.sh,v 1.24 2004/02/26 17:29:43 azarah Exp $
 
 source /etc/init.d/functions.sh
 
@@ -51,7 +51,7 @@ bash "${svcdir}/depcache" | \
 	-f /lib/rcscripts/awk/gendepends.awk || \
 	retval=1
 
-eend ${retval} "Failed to cache service dependencies"
+#eend ${retval} "Failed to cache service dependencies"
 
 exit ${retval}
 
